@@ -44,6 +44,7 @@
 
 #include <ctype.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "cmds.h"
 #include "cmds_edit.h"
@@ -360,12 +361,12 @@ void do_normalmode(struct block * buf) {
 
             } else if (buf->pnext->value == L'f') {                        // gf
                 unselect_ranges();
-                ui_update(TRUE);
-                ui_stop_screen();
+                def_prog_mode();
+                endwin();
                 openfile_under_cursor(sh->currow, sh->curcol);
-                ui_start_screen();
-                start_default_ucolors();
-                set_colors_param_dict();
+                reset_prog_mode();
+                refresh();
+                ui_update(TRUE);
 
             } else if (buf->pnext->value == L'g') {                        // gg
                 e = go_home(sh);
@@ -915,7 +916,7 @@ void do_normalmode(struct block * buf) {
         case L'P':
         case L'T':
             if (bs != 2) break;
-            if (buf->pnext->value == L'v' || buf->pnext->value == L'f' || buf->pnext->value == L'c') {
+            if (buf->pnext->value == L'v' || buf->pnext->value == L'f' || buf->pnext->value == L'c' || buf->pnext->value == L't') {
                 int res = buf->value == L'P' ? paste_yanked_ents(sh, 0, buf->pnext->value) : paste_yanked_ents(sh, 1, buf->pnext->value); // paste cell above or right
                 if (res == -1) {
                     sc_error("Locked cells encountered. Nothing changed");
