@@ -158,7 +158,10 @@ char * get_xlsx_number_format_by_id(xmlDocPtr doc_styles, int id) {
 
     // we go forward up to numFmts section
     xmlNode * cur_node = xmlDocGetRootElement(doc_styles)->xmlChildrenNode;
-    while (cur_node != NULL && !(cur_node->type == XML_ELEMENT_NODE && !strcmp((char *) cur_node->name, "numFmts")))
+    //while (cur_node != NULL && !(cur_node->type == XML_ELEMENT_NODE && !strcmp((char *) cur_node->name, "numFmts")))
+    while ((cur_node != NULL) && !(cur_node->type == XML_ELEMENT_NODE &&
+            (!strcmp((char *) cur_node->name, "numFmts") || !strcmp((char *) cur_node->name, "cellStyleXfs") ||
+            !strcmp((char *) cur_node->name, "cellXfs"))))
         cur_node = cur_node->next;
 
     cur_node = cur_node->xmlChildrenNode;
@@ -304,7 +307,7 @@ void get_sheet_data(xmlDocPtr doc, xmlDocPtr doc_strings, xmlDocPtr doc_styles)
                 } else if (
                 child_node->xmlChildrenNode != NULL && ! strcmp((char *) child_node->xmlChildrenNode->name, "f")) {
 
-                    // handle the formula if that is whats desidered!!
+                    // handle the formula if that is what's desidered!!
                     if (get_conf_int("xlsx_readformulas") &&
                         // dont handle shared formulas right now
                         ! (xmlHasProp(child_node->xmlChildrenNode, (xmlChar *) "t") &&
@@ -573,7 +576,7 @@ int export_xlsx(char * filename) {
     struct sheet * sh = roman->first_sh;
     while (sh != NULL) {
 
-        lxw_worksheet * worksheet = workbook_add_worksheet(workbook, NULL);
+        lxw_worksheet * worksheet = workbook_add_worksheet(workbook, sh->name);
         int bkp_currow = sh->currow;
         sh->currow = 0;
         insert_row(sh, 0); //add a row so that scim formulas apply to excel
