@@ -63,6 +63,7 @@
 #include "macros.h"
 #include "tui.h"
 #include "input.h"
+#include "cmds/cmds_visual.h"
 #include "marks.h"
 #include "format.h"
 #include "maps.h"
@@ -153,7 +154,7 @@ extern graphADT graph;
  * \brief The main() function
  *
  * \details The main() function of sc-im. It is the first function called when
- * the applicaiton is executed.
+ * the application is executed.
  *
  * \param[in] argc (argument count) is the number of strings pointed to by argv. This
  * is passed to main() by the system.
@@ -267,23 +268,22 @@ int main (int argc, char ** argv) {
      * readfile_argv(argc, argv);
      */
 
+    create_empty_wb();
+
+    /*
+     * load_rc. Since we are not sure what people put in their scimrc file,
+     * other than configuration variables and mappings,
+     * we call the load_rc() routine after session / roman / sheet are alloc'ed.
+     * See entire 778 issue and 783 PR for details on why this order is set.
+     */
+    load_rc();
+
     /* load file passed as argv to sc-im.
      * if more than one file is passed, consider the last one.
      */
-    load_file(strlen(loadingfile) ? loadingfile : NULL);
+    if (strlen(loadingfile))
+        load_file(loadingfile);
 
-    /*
-     * check if session->cur_doc is NULL (no file passed as argv).
-     * if so, create an empty doc with just one sheet
-     */
-    if (session->cur_doc == NULL) create_empty_wb();
-
-    /*
-     * load_rc. Since we are not sure what people put it their scimrc file,
-     * other than configuration variables and mappings,
-     * we call the load_rc() routine after session / roman / sheet are alloc'ed.
-     */
-    load_rc();
 
     // check input from stdin (pipeline)
     // and send it to interp
@@ -587,7 +587,7 @@ void handle_argv_exports() {
 
 
 /**
- * \brief Set up signals catched by sc-im
+ * \brief Set up signals caught by sc-im
  * \return none
  */
 void signals() {
@@ -656,6 +656,14 @@ void sig_cont() {
  * \return none
  */
 void sig_int() {
+    sc_info("Got SIGINT.%s" , curmode != NORMAL_MODE ? " Back to NORMAL_MODE" : " Press «:q<Enter>» to quit sc-im");
+    if (get_bufsize(buffer)) break_waitcmd_loop(buffer);
+    if (curmode == VISUAL_MODE) exit_visualmode();
+    chg_mode('.');
+    inputline[0] = L'\0';  // clean inputline
+    flush_buf(buffer);
+    ui_update(TRUE);
+    /*
     if ( ! get_conf_int("debug")) {
         sc_error("Got SIGINT. Press «:q<Enter>» to quit sc-im");
     } else if (get_bufsize(buffer)) {
@@ -663,6 +671,7 @@ void sig_int() {
     } else {
         shall_quit = 2;
     }
+    */
     return;
 }
 
