@@ -478,9 +478,9 @@ extern char * findhome(char * path);
 extern char * r_name(int r1, int c1, int r2, int c2);
 extern char * scxmalloc(unsigned n);
 extern char * scxrealloc(char * ptr, unsigned n);
-extern char * seval(struct sheet * sh, struct ent * ent, struct enode * se);
+extern char * seval(struct sheet * sh, struct ent * ent, struct enode * se, int rebuild_graph);
 extern char * v_name(int row, int col);
-extern double eval(struct sheet * sh, struct ent * ent, struct enode * e);
+extern double eval(struct sheet * sh, struct ent * ent, struct enode * e, int rebuild_graph);
 extern struct enode * new(int op, struct enode * a1, struct enode * a2);
 extern struct enode * new_const(int op, double a1);
 extern struct enode * new_range(int op, struct range_s a1);
